/*
Tiny Thread test program
- generates 1Khz and 60Hz simultaneously
- 1Khz tones are turned off/on every secondf
- demonstrates how to use Tiny Threads
- compile under Hitech PICC compiler
by: Regulus Berdin
*/
#include <pic.h>
#include "tthread.h"
#define FOSC 20000000L 

#define DELAY_MS(D) (FOSC*(D)/4/256/1000)

__CONFIG(HS & WDTDIS & PWRTEN & BOREN & LVPDIS);

unsigned int delay1, delay2, delay3;

void interrupt isr(void)
{
	if (T0IF) {
		T0IF = 0;
		if (delay1)
			--delay1;
		if (delay2)
			--delay2;
		if (delay3)
			--delay3;
	}
}

void init(void)
{
	ADCON1 = 0x06;
	TRISA = 0b00001011;
	PORTA = 0;
	
	TRISB=0b00000000;
	PORTB=0;
	
	TRISC=0;
	PORTC=0;
	
	OPTION=0b10001000;
	//	     1-------	pullups disabled
	//       -0------	int on falling edge
	//		 --0-----	TMR0 on internal clock
	//		 ---0----	inc on low to high trans
	//		 ----1---	prescaler on wdt
	//		 -----000	div by 2
	
	
	T0IF = 0;
	T0IE = 1;
	GIE = 1;
}


TT_DEF(60Hz)
{
	TT_BEGIN(60Hz);
	while(1)
	{
		RB0=1;
		delay1=163;
		TT_WAIT_UNTIL(60Hz, delay1==0);
		RB0=0;
		delay1=163;
		TT_WAIT_WHILE(60Hz, delay1>0);
	}
	TT_END(60Hz);
}


TT_DEF(1KHz)
{
	TT_BEGIN(1KHz);
	while(1)
	{
		RB1=1;
		delay2=10;
		TT_WAIT_UNTIL(1KHz,delay2==0);
		RB1=0;
		delay2=10;
		TT_WAIT_WHILE(1KHz,delay2>0);
	}
	TT_END(1KHz);
}


void main(void)
{
	init();
	
	while(1)
	{
	
		TT_SCHED(60Hz);
		TT_SCHED(1KHz);
		
		if (delay3==0) 
		{
			delay3=19531;
			if TT_IS_RUNNING(1KHz) 
			{
				TT_KILL(1KHz);
			} 
			else 
			{
				TT_INIT(1KHz);
			}
		}
		
	}
}


